Developers — Pootle 2.5.0-rc1 documentation

# Developers

If you are a developer and are willing to hack on Pootle or contribute in some other way, make sure to read through this part.

- Contributing
  - Reporting bugs
  - Translating
  - Documentation
- Hacking
  - Before doing anything
  - Setting up the development environment
  - Workflow
  - Commits
- Customizing the look
  - Customizing CSS
  - Customizing images
  - Customizing the favicon
  - Customizing templates
- Unit Testing
- Release process
  - The release train: point releases every three months
  - Version numbering
  - Branching strategy
- Glossary
- Styleguide
  - Python and documentation
  - JavaScript
  - HTML
  - CSS